@@ -449,7 +449,7 @@ def main():
 
     # get and check options
     args = None
-    if (len(sys.argv) == 1 or sys.argv[1] == '-h' or sys.argv == '--help'):
+    if len(sys.argv) == 1 or sys.argv[1] == '-h' or sys.argv == '--help':
         print_help()
         sys.exit(0)
     else:
@@ -463,7 +463,7 @@ def main():
     # do what we came here to do
     try:
         parser = OptionsParser()
-        if (False):
+        if False:
             # import pstats
             # p = pstats.Stats('prof')
             # p.sort_stats('cumulative').print_stats(10)
