@@ -36,7 +36,7 @@ from gtdb_validation_tk.common import (placeholder_genus,
 from gtdb_validation_tk.suffix_table import SuffixTable, increment_suffix
 
 
-class Backfill():
+class Backfill(object):
     """Fill in missing rank information."""
 
     def __init__(self, prefix, output_dir):
