@@ -48,10 +48,10 @@ from gtdb_validation_tk.spellchecker import SpellChecker
 
 from numpy import mean as np_mean
 
-csv.field_size_limit(sys.maxsize)
+csv.field_size_limit(min(2**31-1, sys.maxsize))
 
 
-class OptionsParser():
+class OptionsParser(object):
     def __init__(self):
         """Initialization"""
         self.logger = logging.getLogger()
@@ -143,7 +143,7 @@ class OptionsParser():
             print('Tree contains polyphyletic groups:')
             for taxon in polyphyletic_groups:
                 if not taxon.startswith('s__') or options.include_species:
-                    print('%s' % (taxon))
+                    print('%s' % taxon)
             print('')
 
         self.logger.info('Finished performing validation tests.')
@@ -766,13 +766,13 @@ class OptionsParser():
         logging.basicConfig(format='', level=logging.INFO)
         if options.subparser_name == 'check_file':
             self.check_file(options)
-        elif(options.subparser_name == 'check_tree'):
+        elif options.subparser_name == 'check_tree':
             self.check_tree(options)
-        elif(options.subparser_name == 'check_suffix'):
+        elif options.subparser_name == 'check_suffix':
             self.check_suffix(options)
-        elif(options.subparser_name == 'check_spelling'):
+        elif options.subparser_name == 'check_spelling':
             self.check_spelling(options)
-        elif(options.subparser_name == 'check_distrib'):
+        elif options.subparser_name == 'check_distrib':
             self.check_distrib(options)
         elif options.subparser_name == 'red_check':
             self.red_check(options)
@@ -786,11 +786,11 @@ class OptionsParser():
             self.red_diff(options)
         elif options.subparser_name == 'tax_diff':
             self.tax_diff(options)
-        elif(options.subparser_name == 'tree_diff'):
+        elif options.subparser_name == 'tree_diff':
             self.tree_diff(options)
-        elif(options.subparser_name == 'retired_taxa'):
+        elif options.subparser_name == 'retired_taxa':
             self.retired_taxa(options)
-        elif(options.subparser_name == 'branch_len'):
+        elif options.subparser_name == 'branch_len':
             self.branch_len(options)
         elif options.subparser_name == 'ncbi_tax_diff':
             self.ncbi_tax_diff(options)
