@@ -332,9 +332,9 @@ class ValidateTypeMaterial(object):
                 
                 type_genomes_in_gtdb = []
                 additional_type_genomes = set(other_type_genomes[ncbi_genus]) - set([gid])
-                for gid in additional_type_genomes:
-                    if gid in input_taxonomy and input_taxonomy[gid][6] == ncbi_genus:
-                        type_genomes_in_gtdb.append(gid)
+                for add_gid in additional_type_genomes:
+                    if add_gid in input_taxonomy and input_taxonomy[add_gid][6] == ncbi_genus:
+                        type_genomes_in_gtdb.append(add_gid)
                 
                 fout.write('{}\t{}\t{}\t{}\t{}\t{}\t{}\t{}\t{}\t{}\t{}\n'.format(
                                 gid, 
